<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Grade;
use App\Classe;
use App\Historique;

class ClasseController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all classes  and pass it to the view
        $classes = Classe::all();

        return view('classes.index')->with('classes', $classes);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $grades = Grade::pluck('title','id' );

        return view('classes.create', compact('grades'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'classe_code' => 'required',
            'classe_name' => 'required',
        ]);

        $classe = new Classe();
        $classe->classe_code = $request->input('classe_code');
        $classe->classe_name = $request->input('classe_name');
        $classe->grade_id = $request->input('grade_id');

        $grade = Grade::findOrFail($classe->grade_id);

        $classe->grade_title = $grade->title;
        $classe->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Classe';
        $historique->user_id = auth()->user()->id;

        $classe->save();
        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('classes.index')
            ->with('success',
             'Nouvelle Classe ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $grades = Grade::pluck('title', 'id');

        $classe = Classe::findOrFail($id);

        return view('classes.edit', compact('classe', 'grades')); //pass classe data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $classe = Classe::findOrFail($id);

        $this->validate($request, [
            'classe_code' => 'required',
            'classe_name' => 'required',
        ]);

        $classe->classe_code = $request->input('classe_code');
        $classe->classe_name = $request->input('classe_name');
        $classe->grade_id = $request->input('grade_id');

        $grade = Grade::findOrFail($classe->grade_id);

        $classe->grade_title = $grade->title;
        $classe->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Classe';
        $historique->user_id = auth()->user()->id;

        $classe->save();
        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('classes.index')
            ->with('success',
             'Classe édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $classe = Classe::findOrFail($id);
        
        $classe->delete();

        return redirect()->route('classes.index')
            ->with('success',
             'Classe supprimé avec succès.');
    }
}
