<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Course;
use App\Grade;
use App\Professor;
use App\Historique;

class CourseController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all courses  and pass it to the view
        $courses = Course::all();

        return view('courses.index')->with('courses', $courses);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $grades = Grade::pluck('title', 'id');

        $professors = Professor::pluck('name','id' );

        return view('courses.create', compact('grades', 'professors'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'course_code' => 'required',
            'course_title' => 'required',
        ]);

        $course = new Course();
        $course->course_code = $request->input('course_code');
        $course->course_title = $request->input('course_title');
        $course->coefficient = $request->input('coefficient');
        $course->hourly_volume = $request->input('hourly_volume');
        $course->grade_id = $request->input('grade_id');
        $course->professor_id = $request->input('professor_id');

        $grade = Grade::findOrFail($course->grade_id);

        $course->grade_title = $grade->title;

        $professor = Professor::findOrFail($course->professor_id);

        $course->professor_name = $professor->name;
        $course->professor_firstname = $professor->firstname;
        $course->professor_email = $professor->email;
        $course->professor_phone = $professor->phone_number;
        $course->professor_address = $professor->address;
        $course->professor_profession = $professor->profession ;
        
        $course->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Course';
        $historique->user_id = auth()->user()->id;

        $course->save();
        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('courses.index')
            ->with('success',
             'Nouvelle Matière ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $course = Course::findOrFail($id);

        $professors = Professor::pluck('name','id');

        $grades = Grade::pluck('title', 'id');

        return view('courses.edit', compact('course', 'grades', 'professors')); //pass classe data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $course = Course::findOrFail($id);

        $this->validate($request, [
            'course_code' => 'required',
            'course_title' => 'required',
        ]);
        
        $course->course_code = $request->input('course_code');
        $course->course_title = $request->input('course_title');
        $course->coefficient = $request->input('coefficient');
        $course->hourly_volume = $request->input('hourly_volume');
        $course->grade_id = $request->input('grade_id');
        $course->professor_id = $request->input('professor_id');

        $grade = Grade::findOrFail($course->grade_id);

        $course->grade_title = $grade->title;

        $professor = Professor::findOrFail($course->professor_id);

        $course->professor_name = $professor->name;
        $course->professor_firstname = $professor->firstname;
        $course->professor_email = $professor->email;
        $course->professor_phone = $professor->phone_number;
        $course->professor_address = $professor->address;
        $course->professor_profession = $professor->profession ;
        
        $course->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Course';
        $historique->user_id = auth()->user()->id;

        $course->save();
        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('courses.index')
            ->with('success',
             'Nouvelle Matière ajouté avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $course = Course::findOrFail($id);
        
        $course->delete();

        return redirect()->route('courses.index')
            ->with('success',
             'Matière supprimé avec succès.');
    }
}
